# PytCube

*PytCube* is a Python library for extracting small **subsets (mini-cubes)** around observation points within large **multidimensional datasets**.

## Installation

`pytcube` is a pure python package. It can easily be installed with pip or conda.

```bash
pip install pytcube
```

```bash
conda install pytcube
```

## Documentation

Learn more about `pytcube` in its official documentation at [https://odatis-public.gitlab-pages.ifremer.fr/pytcube/](https://odatis-public.gitlab-pages.ifremer.fr/pytcube/)
